@@ -10,7 +10,12 @@ from .edge_transformer import EdgeTransformer
 class GraphTransformer:
     """GraphTransformer class to convert graphs to edge embeddings."""
 
-    def __init__(self, method: str = "Hadamard"):
+    def __init__(
+        self,
+        method: str = "Hadamard",
+        aligned_node_mapping: bool = False,
+        support_mirror_strategy: bool = False,
+    ):
         """Create new GraphTransformer object.
 
         Parameters
@@ -18,8 +23,36 @@ class GraphTransformer:
         method: str = "hadamard",
             Method to use for the embedding.
             Can either be 'Hadamard', 'Sum', 'Average', 'L1', 'AbsoluteL1', 'L2' or 'Concatenate'.
+        aligned_node_mapping: bool = False,
+            This parameter specifies whether the mapping of the embeddings nodes
+            matches the internal node mapping of the given graph.
+            If these two mappings do not match, the generated edge embedding
+            will be meaningless.
+        support_mirror_strategy: bool = False,
+            Wethever to patch support for mirror strategy.
+            At the time of writing, TensorFlow's MirrorStrategy does not support
+            input values different from floats, therefore to support it we need
+            to convert the unsigned int 32 values that represent the indices of
+            the embedding layers we receive from Ensmallen to floats.
+            This will generally slow down performance, but in the context of
+            exploiting multiple GPUs it may be unnoticeable.
         """
-        self._transformer = EdgeTransformer(method=method)
+        self._transformer = EdgeTransformer(
+            method=method,
+            aligned_node_mapping=aligned_node_mapping,
+            support_mirror_strategy=support_mirror_strategy
+        )
+        self._aligned_node_mapping = aligned_node_mapping
+
+    @property
+    def numeric_node_ids(self) -> bool:
+        """Return whether the transformer returns numeric node IDs."""
+        return self._transformer.numeric_node_ids
+
+    @property
+    def method(self) -> str:
+        """Return the used edge embedding method."""
+        return self._transformer.method
 
     def fit(self, embedding: pd.DataFrame):
         """Fit the model.
@@ -36,7 +69,10 @@ class GraphTransformer:
         """
         self._transformer.fit(embedding)
 
-    def transform(self, graph: Union[EnsmallenGraph, np.ndarray, List[List[str]], List[List[int]]], aligned_node_mapping: bool = False) -> np.ndarray:
+    def transform(
+        self,
+        graph: Union[EnsmallenGraph, np.ndarray, List[List[str]], List[List[int]]],
+    ) -> np.ndarray:
         """Return edge embedding for given graph using provided method.
 
         Parameters
@@ -44,11 +80,6 @@ class GraphTransformer:
         graph: Union[EnsmallenGraph, np.ndarray, List[List[str]], List[List[int]]],
             The graph whose edges are to embed.
             It can either be an EnsmallenGraph or a list of lists of edges.
-        aligned_node_mapping: bool = False,
-            This parameter specifies wheter the mapping of the embeddings nodes
-            matches the internal node mapping of the given graph.
-            If these two mappings do not match, the generated edge embedding
-            will be meaningless.
 
         Raises
         --------------------------
@@ -60,7 +91,7 @@ class GraphTransformer:
         Numpy array of embeddings.
         """
         if isinstance(graph, EnsmallenGraph):
-            if aligned_node_mapping:
+            if self._aligned_node_mapping:
                 graph = graph.get_edges(directed=False)
             else:
                 graph = graph.get_edge_names(directed=False)
@@ -69,4 +100,4 @@ class GraphTransformer:
         if isinstance(graph, np.ndarray):
             sources = graph[:, 0]
             destinations = graph[:, 1]
-        return self._transformer.transform(sources, destinations, aligned_node_mapping)
+        return self._transformer.transform(sources, destinations)
